@@ -119,6 +119,7 @@ class LocalCall(object):
         def writeFile(self):
             """ write data in file """
             from calculate.core.server.gen_pid import ProcessMode
+
             if os.getuid():
                 return
             pid = os.getpid()
@@ -129,6 +130,7 @@ class LocalCall(object):
             build_id = ""
             try:
                 from calculate.builder.variables.action import Actions
+
                 if self.clVars.Get('cl_action') in Actions.All:
                     build_id = self.clVars.Get('builder.cl_builder_id')
             except Exception:
@@ -160,7 +162,7 @@ def cout_progress(string=None):
         h, w = array('h', ioctl(sys.stderr, termios.TIOCGWINSZ, '\0' * 8))[:2]
     except IOError:
         return
-    sys.stdout.write('\r' + (' ' * (w)))
+    sys.stdout.write('\r' + (' ' * w))
     if string:
         sys.stdout.write('\r' + string)
     else:
@@ -209,10 +211,10 @@ def local_method(metaclass, args, unknown_args):
         try:
             method_parser = get_method_argparser(view, args, cl_core=True)
         except Exception:
-            #import traceback
-            #for i in apply(traceback.format_exception, sys.exc_info()):
+            # import traceback
+            # for i in apply(traceback.format_exception, sys.exc_info()):
             #    sys.stderr.write(i)
-            #sys.stderr.flush()
+            # sys.stderr.flush()
             metaObject.clear_cache(0, method_name)
             return 1
         method_parser.print_help()
@@ -223,15 +225,15 @@ def local_method(metaclass, args, unknown_args):
             return metaObject.method_status
         except (ValueError, CriticalError) as e:
             colorPrint.printERROR(str(e))
-            #colorPrint.printERROR(shortTraceback(*sys.exc_info()))
+            # colorPrint.printERROR(shortTraceback(*sys.exc_info()))
         except (KeyboardInterrupt, EOFError):
             colorPrint.printERROR(_('Manually interrupted'))
-        except (GotErrorField,) as e:
+        except (GotErrorField,):
             pass
         except Exception:
             colorPrint.printERROR(shortTraceback(*sys.exc_info()))
             pass
-        #            print 'Error: ', e
+            #            print 'Error: ', e
     metaObject.clear_cache(0, method_name)
 
 
@@ -264,7 +266,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         args, unknown_args = method_parser.parse_known_args(unknown_args)
         no_questions = args.no_questions
         metaObject.no_questions = no_questions
-    except SystemExit as e:
+    except SystemExit:
         return 1
     except Exception:
         import traceback
@@ -323,7 +325,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         if not no_questions:
             if stdin_passwd:
                 colorPrint.printERROR("Could not use the interactive mode. "
-                          "Use option '-f' for run the process.")
+                                      "Use option '-f' for run the process.")
                 return None
             try:
                 ask = ResultViewer().askConfirm(_("Run process?"))
@@ -345,12 +347,12 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     for ReturnedMessage in method_result:
         if ReturnedMessage.type and ReturnedMessage.type != "pid":
             display_error(ReturnedMessage, args, view.groups)
-            #params_text = ''
-            #for Group in view.groups:
+            # params_text = ''
+            # for Group in view.groups:
             #    for field in Group.fields:
             #        if field.name == ReturnedMessage.field:
             #            params_text += getErrorOnParam(args, field)
-            #colorPrint.printERROR('\r' + params_text % \
+            # colorPrint.printERROR('\r' + params_text % \
             #                      str(ReturnedMessage.message))
             return None
     return method_result
@@ -429,7 +431,7 @@ class Display(object):
         ColorTable(head, data, self._print,
                    body_printer=self._print.foreground(
                        WHITE).clone()).printReport(False)
-        #sys.stdout.write('%s\n' % printTable(data, head))
+        # sys.stdout.write('%s\n' % printTable(data, head))
 
     def print_group(self, label):
         self._print(label)
@@ -447,20 +449,20 @@ class InformationElement(object):
         if field.type == 'steps':
             return None
         map_elements = {'input': ValueInfo,
-                       'openfile': ValueInfo,
-                       'combo': ChoiceInfo,
-                       'comboEdit': ChoiceInfo,
-                       'radio': ChoiceInfo,
-                       'file': ChoiceInfo,
-                       'multichoice': MultiChoiceInfo,
-                       'multichoice_add': MultiChoiceInfo,
-                       'selecttable': MultiChoiceInfo,
-                       'selecttable_add': MultiChoiceInfo,
-                       'error': ErrorInfo,
-                       'check': CheckInfo,
-                       'check_tristate': CheckInfo,
-                       'table': TableInfo
-                       }
+                        'openfile': ValueInfo,
+                        'combo': ChoiceInfo,
+                        'comboEdit': ChoiceInfo,
+                        'radio': ChoiceInfo,
+                        'file': ChoiceInfo,
+                        'multichoice': MultiChoiceInfo,
+                        'multichoice_add': MultiChoiceInfo,
+                        'selecttable': MultiChoiceInfo,
+                        'selecttable_add': MultiChoiceInfo,
+                        'error': ErrorInfo,
+                        'check': CheckInfo,
+                        'check_tristate': CheckInfo,
+                        'table': TableInfo
+                        }
         if field.element in map_elements:
             return map_elements[field.element](field, display)
         return None
@@ -475,13 +477,15 @@ class ValueInfo(InformationElement):
         self.value = field.value or ''
         self.label = field.label
 
+
 class CheckInfo(InformationElement):
     def __init__(self, field, display):
         super(CheckInfo, self).__init__(field, display)
         self.label = field.label
-        map_answer = {'on':_('yes'), 'off': _("no"), 'auto': _('auto')}
+        map_answer = {'on': _('yes'), 'off': _("no"), 'auto': _('auto')}
         self.value = map_answer.get(field.value, field.value)
 
+
 class ChoiceInfo(InformationElement):
     def __init__(self, field, display):
         super(ChoiceInfo, self).__init__(field, display)
@@ -526,7 +530,7 @@ class TableInfo(InformationElement):
     """
 
     def map_row(self, row, typedata):
-        map_answer = {'on':_('yes'), 'off': _("no"), 'auto': _('auto')}
+        map_answer = {'on': _('yes'), 'off': _("no"), 'auto': _('auto')}
         for cell, typefield in izip(row, typedata):
             if typefield in ['check', 'check_tristate']:
                 yield map_answer.get(cell, cell) or ""
@@ -561,8 +565,8 @@ def print_brief_group(Fields, group_name):
     try:
         for element in ifilter(None,
                                (InformationElement.from_field(
-                                       FieldAdapter.from_detect(x),
-                                       display)
+                                   FieldAdapter.from_detect(x),
+                                   display)
                                 for x in Fields if not x.uncompatible)):
             if show_group:
                 display.print_group(group_name)
@@ -570,6 +574,7 @@ def print_brief_group(Fields, group_name):
             element.show()
     except Exception:
         import traceback
+
         traceback.print_exc()
         raise
 
