@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2011-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2011-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,24 +13,26 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from calculate.lib.datavars import Variable,ReadonlyVariable,VariableError
-import os, glob, sys
-from os import path
+from calculate.lib.datavars import Variable, ReadonlyVariable, VariableError
+import os
+import sys
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.files import readLinesFile,pathJoin, listDirectory
+from calculate.lib.utils.files import pathJoin, listDirectory
 from calculate.core.server.loaded_methods import LoadedMethods
 from calculate.core.server.func import uniq
-#from calculate.api.cert_cmd import find_id_cert
-setLocalTranslate('cl_core3',sys.modules[__name__])
+
+_ = lambda x: x
+setLocalTranslate('cl_core3', sys.modules[__name__])
+
 
 class VariableClListCertId(ReadonlyVariable):
-
     def get(self):
-        cert_dir =  self.Get('cl_core_client_certs_path')
-        return map(lambda x:x[:-4],
-               filter(lambda x:x.endswith('.crt'),
-               listDirectory(cert_dir)))
+        cert_dir = self.Get('cl_core_client_certs_path')
+        return map(lambda x: x[:-4],
+                   filter(lambda x: x.endswith('.crt'),
+                          listDirectory(cert_dir)))
+
 
 class VariableClCertId(Variable):
     """
@@ -48,16 +50,17 @@ class VariableClCertId(Variable):
         return self.Get('cl_list_cert_id')
 
     def check(self, cert_id):
-#        if cert_id != 'all':
+        #        if cert_id != 'all':
         try:
             int(cert_id)
         except ValueError:
             raise VariableError(_("The certificate ID must be int"))
-        
+
         list_certs_id = self.Get('cl_list_cert_id')
-        if not cert_id in list_certs_id:
-            raise VariableError(_("The certificate with ID %s not exists") \
-                                %cert_id)
+        if cert_id not in list_certs_id:
+            raise VariableError(_("The certificate with ID %s not exists")
+                                % cert_id)
+
 
 class VariableClCertPerms(Variable):
     """
@@ -87,6 +90,7 @@ class VariableClCertPerms(Variable):
         group_rights = self.Get('cl_core_group_rights_path')
         rights = self.Get('cl_core_rights')
         # if group = all and not redefined group all
+        results = []
         if 'all' in groups_list:
             find_flag = False
             fd = open(group_rights, 'r')
@@ -102,23 +106,20 @@ class VariableClCertPerms(Variable):
                 right_list = []
                 for key in LoadedMethods.rightsMethods.keys():
                     right_list += LoadedMethods.rightsMethods[key]
-        
+
                 uniq_right_list = uniq(right_list)
                 uniq_right_list.sort()
                 return uniq_right_list
-#                self.printSUCCESS(_("Certificate %d can call all "
-#                                    "methods!")%cert_id)
 
         else:
-            results = []
-            if not os.path.exists (group_rights):
+            if not os.path.exists(group_rights):
                 open(group_rights, 'w')
             with open(group_rights) as fd:
                 t = fd.read()
                 for line in t.splitlines():
                     if not line:
                         continue
-                    words = line.split(' ',1)
+                    words = line.split(' ', 1)
                     # first word in line equal name input method
                     if words[0] in groups_list:
                         methods = words[1].split(',')
@@ -138,7 +139,7 @@ class VariableClCertPerms(Variable):
                     for word in words:
                         try:
                             word = int(word)
-                        except:
+                        except ValueError:
                             continue
                         # compare with certificat number
                         if cert_id == word:
@@ -152,9 +153,9 @@ class VariableClCertPerms(Variable):
 
             for method in results:
                 if method in del_list_rights:
-                    results.remove(method)  
+                    results.remove(method)
 
-            if results == []:
+            if not results:
                 results.append("No Methods")
 
         return results
@@ -162,13 +163,14 @@ class VariableClCertPerms(Variable):
     def uncompatible(self):
         return _('You cannot change the certificate permissions')
 
+
 class VariableClCertGroups(Variable):
     """
     Certificate Groups
     """
     type = "choice-list"
-#    opt = ["--cert-group"]
-#    metavalue = "perm[,perm2[..]]"
+    #    opt = ["--cert-group"]
+    #    metavalue = "perm[,perm2[..]]"
 
     def init(self):
         self.help = _("Certificate groups")
@@ -177,40 +179,48 @@ class VariableClCertGroups(Variable):
     def choice(self):
         group_rights = self.Get('cl_core_group_rights_path')
 
-        t = open(group_rights, 'r').read()
-        result = []
-        for line in t.splitlines():
-            words = line.split()
-            if words and len(words):
-                if not words[0].startswith('#'):
-                    result.append(words[0])
-        if not 'all' in result:
-            result.append('all')
+        with open(group_rights, 'r') as f:
+            t = f.read()
+            result = []
+            for line in t.splitlines():
+                words = line.split()
+                if words and len(words):
+                    if not words[0].startswith('#'):
+                        result.append(words[0])
+            if 'all' not in result:
+                result.append('all')
         return result
 
     def get(self):
         try:
             import OpenSSL
-            cert_file = self.Get('cl_cert_crt_path')
 
-            cert = open(cert_file, 'r').read()
-            certobj = OpenSSL.crypto.load_certificate \
-                                           (OpenSSL.SSL.FILETYPE_PEM, cert)
-            com = certobj.get_extension(certobj.get_extension_count()-1). \
-                                        get_data()
-            groups = com.rpartition(':')[2]
-            groups_list = groups.split(',')
-            return groups_list
-        except (OpenSSL.crypto.Error,IOError, ImportError) as e:
+            try:
+                cert_file = self.Get('cl_cert_crt_path')
+
+                with open(cert_file, 'r') as f:
+                    cert = f.read()
+                certobj = OpenSSL.crypto.load_certificate(
+                    OpenSSL.SSL.FILETYPE_PEM, cert)
+                com = certobj.get_extension(
+                    certobj.get_extension_count() - 1).get_data()
+                groups = com.rpartition(':')[2]
+                groups_list = groups.split(',')
+                return groups_list
+            except OpenSSL.crypto.Error:
+                return []
+        except (IOError, ImportError):
             return []
 
     def uncompatible(self):
         return _('You cannot change the certificate permissions')
 
+
 class VariableClCertCrtPath(Variable):
     """
     Путь до сертификата (при указании иденификатора сертификата)
     """
+
     def get(self):
         return pathJoin(self.Get('cl_core_client_certs_path'),
-                        "%s.crt"%self.Get('cl_cert_id'))
+                        "%s.crt" % self.Get('cl_cert_id'))
